@@ -31,6 +31,9 @@ dLG<-function(x, mu = 0.5, log = FALSE)
  { 
           if (any(mu <= 0) | any(mu >= 1) )  stop(paste("mu must be greater than 0 and less than 1", "\n", ""))
           if (any(x <= 0) )  stop(paste("x must be >0", "\n", ""))
+      ly <- max(length(x),length(mu)) 
+       x <- rep(x, length = ly)      
+      mu <- rep(mu, length = ly)   
        logfy <- x*log(mu)-log(x)-log(-log(1-mu))
       if(log == FALSE) fy <- exp(logfy) else fy <- logfy
           fy
@@ -39,8 +42,10 @@ dLG<-function(x, mu = 0.5, log = FALSE)
 pLG <- function(q, mu = 0.5, lower.tail = TRUE, log.p = FALSE)
   {     
           if (any(mu <= 0) | any(mu >= 1) )  stop(paste("mu must be greater than 0 and less than 1", "\n", ""))
-   if (any(q <= 0) )  stop(paste("q must be >0", "\n", ""))    
-        ly <- length(q)                                                       
+   if (any(q <= 0) )  stop(paste("q must be >0", "\n", "")) 
+        ly <- max(length(q),length(mu)) 
+         q <- rep(q, length = ly)      
+        mu <- rep(mu, length = ly)   
        FFF <- rep(0,ly)                         
        nmu <- rep(mu, length = ly)                                                       
          j <- seq(along=q) 
