@@ -103,7 +103,10 @@ dNBF<-function(x, mu=1, sigma=1, nu=2, log=FALSE)
   if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
   if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
   if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
-  #browser()
+    ly <- max(length(x),length(mu), length(sigma)) 
+       x <- rep(x, length = ly)      
+      mu <- rep(mu, length = ly) 
+   sigma <- rep(sigma, length = ly) 
      mu1 <- mu
   sigma1 <- sigma*mu^(nu-2)
   if (length(sigma1)>1) 
@@ -119,6 +122,10 @@ pNBF <- function(q, mu=1, sigma=1, nu=2, lower.tail = TRUE, log.p = FALSE)
   if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
   if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
   if (any(q < 0) )  stop(paste("q must be >=0", "\n", ""))
+      ly <- max(length(q),length(mu), length(sigma)) 
+       q <- rep(q, length = ly)      
+      mu <- rep(mu, length = ly) 
+   sigma <- rep(sigma, length = ly)
      mu1 <- mu
   sigma1 <- sigma*mu^(nu-2)
   if (length(sigma1)>1) cdf <- ifelse(sigma1>0.0001, pnbinom(q, size=1/sigma1, mu=mu1, lower.tail=lower.tail,log.p=log.p), 
