@@ -71,9 +71,13 @@ dZIP2<-function(x, mu = 5, sigma = 0.1, log = FALSE)
           if (any(mu <= 0) )  stop(paste("mu must be greater than 0", "\n", ""))           
           if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
           if (any(x < 0) )  stop(paste("x must be 0 or greater than 0", "\n", ""))   
-           mus <- mu/(1-sigma)
-         logfy <- rep(0, length(x))
-         logfy <- ifelse((x==0), log(sigma+(1-sigma)*exp(-mus)), 
+           ly <- max(length(x),length(mu),length(sigma)) 
+            x <- rep(x, length = ly)      
+        sigma <- rep(sigma, length = ly)
+           mu <- rep(mu, length = ly)   
+          mus <- mu/(1-sigma)
+        logfy <- rep(0, length(x))
+        logfy <- ifelse((x==0), log(sigma+(1-sigma)*exp(-mus)), 
                                   ((1-x)*log(1-sigma) - mus +x*log(mu) -lgamma(x+1)))          
           if(log == FALSE) fy <- exp(logfy) else fy <- logfy
           fy
@@ -83,7 +87,11 @@ pZIP2 <- function(q, mu = 5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
   {     
          if (any(mu <= 0) )  stop(paste("mu must be greater than 0", "\n", ""))           
          if (any(sigma <= 0) | any(sigma >= 1) )  stop(paste("sigma must be between 0 and 1", "\n", "")) 
-         if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", ""))  
+         if (any(q < 0) )  stop(paste("y must be 0 or greater than 0", "\n", "")) 
+          ly <- max(length(q),length(mu),length(sigma)) 
+           q <- rep(q, length = ly)      
+       sigma <- rep(sigma, length = ly)
+          mu <- rep(mu, length = ly) 
          mus <- mu/(1-sigma)
          cdf <- rep(0,length(q))
          cdf <- ppois(q, lambda = mus, lower.tail = TRUE, log.p = FALSE)
@@ -100,6 +108,10 @@ qZIP2 <- function(p, mu = 5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
          if (any(p <= 0) | any(p >= 1))  stop(paste("p must be between 0 and 1", "\n", "")) 
          if (log.p == TRUE) p <- exp(p)   else p <- p
          if (lower.tail == TRUE)  p <- p  else p <- 1 - p
+            ly <- max(length(p),length(mu),length(sigma)) 
+             p <- rep(p, length = ly)      
+         sigma <- rep(sigma, length = ly)
+            mu <- rep(mu, length = ly)
            mus <- mu/(1-sigma)
           pnew <- (p-sigma)/(1-sigma)-1e-10
           suppressWarnings(q <- ifelse((pnew > 0 ), qpois(pnew, lambda = mus, ), 0))
